@@ -26,6 +26,14 @@ class ComposedLink(TerminatingLink):
 
         return value
 
+    async def aconnect(self):
+        for link in self.links:
+            await link.aconnect()
+
+    async def adisconnect(self):
+        for link in self.links:
+            await link.adisconnect()
+
     async def __aenter__(self):
         for i in range(len(self.links) - 1):
             self.links[i].set_next(self.links[i + 1])
@@ -37,19 +45,10 @@ class ComposedLink(TerminatingLink):
         for link in self.links:
             await link.__aexit__(*args, **kwargs)
 
-    async def aquery(self, operation: Operation, **kwargs):
-        return await self.links[0].aquery(operation)
-
-    async def asubscribe(self, operation: Operation, **kwargs):
-        async for result in self.links[0].asubscribe(operation):
+    async def aexecute(self, operation: Operation, **kwargs):
+        async for result in self.links[0].aexecute(operation):
             yield result
 
-    def query(self, operation: Operation, **kwargs):
-        return self.links[0].query(operation, **kwargs)
-
-    def subscribe(self, operation: Operation, **kwargs):
-        return self.links[0].subscribe(operation, **kwargs)
-
 
 def compose(*links: List[Link]) -> ComposedLink:
     """
