@@ -46,11 +46,11 @@ class InvalidPayload(TerminatingLinkError):
 
 
 async def none_token_loader():
-    return None
+    raise Exception("Token loader was not set")
 
 
 class WebSocketLink(AsyncTerminatingLink):
-    url: str
+    ws_endpoint_url: str
     allow_reconnect: bool = False
     time_between_retries = 1
     max_retries = 3
@@ -68,20 +68,25 @@ class WebSocketLink(AsyncTerminatingLink):
         await self._send_queue.put(message)
 
     async def __aenter__(self):
-        logger.info("Connecting Websockets")
         self._ongoing_subscriptions = {}
         self._send_queue = asyncio.Queue()
+
+    async def aconnect(self):
+        logger.info("Connecting Websockets")
         self._connection_task = asyncio.create_task(self.websocket_loop())
         self._connected = True
 
+    async def adisconnect(self):
+        self._connection_task.cancel()
+
+        try:
+            await self._connection_task
+        except asyncio.CancelledError:
+            logger.info(f"Websocket Transport {self} succesfully disconnected")
+
     async def __aexit__(self, *args, **kwargs):
         if self._connection_task:
-            self._connection_task.cancel()
-
-            try:
-                await self._connection_task
-            except asyncio.CancelledError:
-                logger.info(f"Websocket Transport {self} succesfully disconnected")
+            await self.adisconnect()
 
     async def websocket_loop(self, retry=0):
         send_task = None
@@ -89,7 +94,11 @@ class WebSocketLink(AsyncTerminatingLink):
         try:
             try:
                 token = await self.token_loader()
-                url = f"{self.url}?token={token}" if token else self.url
+                url = (
+                    f"{self.ws_endpoint_url}?token={token}"
+                    if token
+                    else self.ws_endpoint_url
+                )
                 async with websockets.connect(
                     url,
                     subprotocols=[GQL_WS_SUBPROTOCOL],
@@ -189,7 +198,7 @@ class WebSocketLink(AsyncTerminatingLink):
             ), "Received Result for subscription that is no longer or was never active"
             await self._ongoing_subscriptions[id].put(message)
 
-    async def asubscribe(self, operation: Operation):
+    async def aexecute(self, operation: Operation):
         if self._connection_task == False:
             raise LinkNotConnectedError("Websocket_link is not connected")
 
@@ -228,42 +237,6 @@ class WebSocketLink(AsyncTerminatingLink):
                 logger.info(f"Subcription done {operation}")
                 return
 
-    async def aquery(self, operation: Operation):
-        assert (
-            operation.node.operation != OperationType.SUBSCRIPTION
-        ), "Operation is a subscription. Only queries are allowed on 'aquery'"
-        assert (
-            operation.context.files is None
-        ), "We cannot send files through websockets"
-
-        id = str(uuid.uuid4())
-        subscribe_queue = asyncio.Queue()
-        self._ongoing_subscriptions[id] = subscribe_queue
-
-        payload = {
-            "headers": operation.context.headers,
-            "query": operation.document,
-            "variables": operation.variables,
-        }
-        frame = {"id": id, "type": GQL_START, "payload": payload}
-        await self.aforward(json.dumps(frame))
-
-        while True:
-            answer = await subscribe_queue.get()
-
-            if answer["type"] == GQL_DATA:
-                payload = answer["payload"]
-
-                if "data" in payload:
-                    subscribe_queue.task_done()
-                    del self._ongoing_subscriptions[id]
-                    return GraphQLResult(data=payload["data"])
-
-            if answer["type"] == GQL_COMPLETE:
-                raise InvalidPayload(
-                    "Subcription done before yielding data. This shouldnt happen for queries"
-                )
-
     class Config:
         arbitrary_types_allowed = True
         underscore_attrs_are_private = True
